#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# exceptions.
class InvalidFormatError(Exception):
	pass
class ArgumentFormatError(Exception):
	pass
class EmptyArgumentError(Exception):
	pass
class ArgumentError(Exception):
	pass
class UnkownArgumentError(Exception):
	pass